@@ -124,70 +124,76 @@ extern int c_debug;
     VAR_DNSTAP = 325,              /* VAR_DNSTAP  */
     VAR_DNSTAP_ENABLE = 326,       /* VAR_DNSTAP_ENABLE  */
     VAR_DNSTAP_SOCKET_PATH = 327,  /* VAR_DNSTAP_SOCKET_PATH  */
-    VAR_DNSTAP_SEND_IDENTITY = 328, /* VAR_DNSTAP_SEND_IDENTITY  */
-    VAR_DNSTAP_SEND_VERSION = 329, /* VAR_DNSTAP_SEND_VERSION  */
-    VAR_DNSTAP_IDENTITY = 330,     /* VAR_DNSTAP_IDENTITY  */
-    VAR_DNSTAP_VERSION = 331,      /* VAR_DNSTAP_VERSION  */
-    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 332, /* VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES  */
-    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 333, /* VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES  */
-    VAR_REMOTE_CONTROL = 334,      /* VAR_REMOTE_CONTROL  */
-    VAR_CONTROL_ENABLE = 335,      /* VAR_CONTROL_ENABLE  */
-    VAR_CONTROL_INTERFACE = 336,   /* VAR_CONTROL_INTERFACE  */
-    VAR_CONTROL_PORT = 337,        /* VAR_CONTROL_PORT  */
-    VAR_SERVER_KEY_FILE = 338,     /* VAR_SERVER_KEY_FILE  */
-    VAR_SERVER_CERT_FILE = 339,    /* VAR_SERVER_CERT_FILE  */
-    VAR_CONTROL_KEY_FILE = 340,    /* VAR_CONTROL_KEY_FILE  */
-    VAR_CONTROL_CERT_FILE = 341,   /* VAR_CONTROL_CERT_FILE  */
-    VAR_KEY = 342,                 /* VAR_KEY  */
-    VAR_ALGORITHM = 343,           /* VAR_ALGORITHM  */
-    VAR_SECRET = 344,              /* VAR_SECRET  */
-    VAR_TLS_AUTH = 345,            /* VAR_TLS_AUTH  */
-    VAR_TLS_AUTH_DOMAIN_NAME = 346, /* VAR_TLS_AUTH_DOMAIN_NAME  */
-    VAR_TLS_AUTH_CLIENT_CERT = 347, /* VAR_TLS_AUTH_CLIENT_CERT  */
-    VAR_TLS_AUTH_CLIENT_KEY = 348, /* VAR_TLS_AUTH_CLIENT_KEY  */
-    VAR_TLS_AUTH_CLIENT_KEY_PW = 349, /* VAR_TLS_AUTH_CLIENT_KEY_PW  */
-    VAR_PATTERN = 350,             /* VAR_PATTERN  */
-    VAR_NAME = 351,                /* VAR_NAME  */
-    VAR_ZONEFILE = 352,            /* VAR_ZONEFILE  */
-    VAR_NOTIFY = 353,              /* VAR_NOTIFY  */
-    VAR_PROVIDE_XFR = 354,         /* VAR_PROVIDE_XFR  */
-    VAR_ALLOW_QUERY = 355,         /* VAR_ALLOW_QUERY  */
-    VAR_AXFR = 356,                /* VAR_AXFR  */
-    VAR_UDP = 357,                 /* VAR_UDP  */
-    VAR_NOTIFY_RETRY = 358,        /* VAR_NOTIFY_RETRY  */
-    VAR_ALLOW_NOTIFY = 359,        /* VAR_ALLOW_NOTIFY  */
-    VAR_REQUEST_XFR = 360,         /* VAR_REQUEST_XFR  */
-    VAR_ALLOW_AXFR_FALLBACK = 361, /* VAR_ALLOW_AXFR_FALLBACK  */
-    VAR_OUTGOING_INTERFACE = 362,  /* VAR_OUTGOING_INTERFACE  */
-    VAR_ANSWER_COOKIE = 363,       /* VAR_ANSWER_COOKIE  */
-    VAR_COOKIE_SECRET = 364,       /* VAR_COOKIE_SECRET  */
-    VAR_COOKIE_SECRET_FILE = 365,  /* VAR_COOKIE_SECRET_FILE  */
-    VAR_MAX_REFRESH_TIME = 366,    /* VAR_MAX_REFRESH_TIME  */
-    VAR_MIN_REFRESH_TIME = 367,    /* VAR_MIN_REFRESH_TIME  */
-    VAR_MAX_RETRY_TIME = 368,      /* VAR_MAX_RETRY_TIME  */
-    VAR_MIN_RETRY_TIME = 369,      /* VAR_MIN_RETRY_TIME  */
-    VAR_MIN_EXPIRE_TIME = 370,     /* VAR_MIN_EXPIRE_TIME  */
-    VAR_MULTI_MASTER_CHECK = 371,  /* VAR_MULTI_MASTER_CHECK  */
-    VAR_SIZE_LIMIT_XFR = 372,      /* VAR_SIZE_LIMIT_XFR  */
-    VAR_ZONESTATS = 373,           /* VAR_ZONESTATS  */
-    VAR_INCLUDE_PATTERN = 374,     /* VAR_INCLUDE_PATTERN  */
-    VAR_STORE_IXFR = 375,          /* VAR_STORE_IXFR  */
-    VAR_IXFR_SIZE = 376,           /* VAR_IXFR_SIZE  */
-    VAR_IXFR_NUMBER = 377,         /* VAR_IXFR_NUMBER  */
-    VAR_CREATE_IXFR = 378,         /* VAR_CREATE_IXFR  */
-    VAR_ZONE = 379,                /* VAR_ZONE  */
-    VAR_RRL_WHITELIST = 380,       /* VAR_RRL_WHITELIST  */
-    VAR_SERVERS = 381,             /* VAR_SERVERS  */
-    VAR_BINDTODEVICE = 382,        /* VAR_BINDTODEVICE  */
-    VAR_SETFIB = 383,              /* VAR_SETFIB  */
-    VAR_VERIFY = 384,              /* VAR_VERIFY  */
-    VAR_ENABLE = 385,              /* VAR_ENABLE  */
-    VAR_VERIFY_ZONE = 386,         /* VAR_VERIFY_ZONE  */
-    VAR_VERIFY_ZONES = 387,        /* VAR_VERIFY_ZONES  */
-    VAR_VERIFIER = 388,            /* VAR_VERIFIER  */
-    VAR_VERIFIER_COUNT = 389,      /* VAR_VERIFIER_COUNT  */
-    VAR_VERIFIER_FEED_ZONE = 390,  /* VAR_VERIFIER_FEED_ZONE  */
-    VAR_VERIFIER_TIMEOUT = 391     /* VAR_VERIFIER_TIMEOUT  */
+    VAR_DNSTAP_IP = 328,           /* VAR_DNSTAP_IP  */
+    VAR_DNSTAP_TLS = 329,          /* VAR_DNSTAP_TLS  */
+    VAR_DNSTAP_TLS_SERVER_NAME = 330, /* VAR_DNSTAP_TLS_SERVER_NAME  */
+    VAR_DNSTAP_TLS_CERT_BUNDLE = 331, /* VAR_DNSTAP_TLS_CERT_BUNDLE  */
+    VAR_DNSTAP_TLS_CLIENT_KEY_FILE = 332, /* VAR_DNSTAP_TLS_CLIENT_KEY_FILE  */
+    VAR_DNSTAP_TLS_CLIENT_CERT_FILE = 333, /* VAR_DNSTAP_TLS_CLIENT_CERT_FILE  */
+    VAR_DNSTAP_SEND_IDENTITY = 334, /* VAR_DNSTAP_SEND_IDENTITY  */
+    VAR_DNSTAP_SEND_VERSION = 335, /* VAR_DNSTAP_SEND_VERSION  */
+    VAR_DNSTAP_IDENTITY = 336,     /* VAR_DNSTAP_IDENTITY  */
+    VAR_DNSTAP_VERSION = 337,      /* VAR_DNSTAP_VERSION  */
+    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 338, /* VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES  */
+    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 339, /* VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES  */
+    VAR_REMOTE_CONTROL = 340,      /* VAR_REMOTE_CONTROL  */
+    VAR_CONTROL_ENABLE = 341,      /* VAR_CONTROL_ENABLE  */
+    VAR_CONTROL_INTERFACE = 342,   /* VAR_CONTROL_INTERFACE  */
+    VAR_CONTROL_PORT = 343,        /* VAR_CONTROL_PORT  */
+    VAR_SERVER_KEY_FILE = 344,     /* VAR_SERVER_KEY_FILE  */
+    VAR_SERVER_CERT_FILE = 345,    /* VAR_SERVER_CERT_FILE  */
+    VAR_CONTROL_KEY_FILE = 346,    /* VAR_CONTROL_KEY_FILE  */
+    VAR_CONTROL_CERT_FILE = 347,   /* VAR_CONTROL_CERT_FILE  */
+    VAR_KEY = 348,                 /* VAR_KEY  */
+    VAR_ALGORITHM = 349,           /* VAR_ALGORITHM  */
+    VAR_SECRET = 350,              /* VAR_SECRET  */
+    VAR_TLS_AUTH = 351,            /* VAR_TLS_AUTH  */
+    VAR_TLS_AUTH_DOMAIN_NAME = 352, /* VAR_TLS_AUTH_DOMAIN_NAME  */
+    VAR_TLS_AUTH_CLIENT_CERT = 353, /* VAR_TLS_AUTH_CLIENT_CERT  */
+    VAR_TLS_AUTH_CLIENT_KEY = 354, /* VAR_TLS_AUTH_CLIENT_KEY  */
+    VAR_TLS_AUTH_CLIENT_KEY_PW = 355, /* VAR_TLS_AUTH_CLIENT_KEY_PW  */
+    VAR_PATTERN = 356,             /* VAR_PATTERN  */
+    VAR_NAME = 357,                /* VAR_NAME  */
+    VAR_ZONEFILE = 358,            /* VAR_ZONEFILE  */
+    VAR_NOTIFY = 359,              /* VAR_NOTIFY  */
+    VAR_PROVIDE_XFR = 360,         /* VAR_PROVIDE_XFR  */
+    VAR_ALLOW_QUERY = 361,         /* VAR_ALLOW_QUERY  */
+    VAR_AXFR = 362,                /* VAR_AXFR  */
+    VAR_UDP = 363,                 /* VAR_UDP  */
+    VAR_NOTIFY_RETRY = 364,        /* VAR_NOTIFY_RETRY  */
+    VAR_ALLOW_NOTIFY = 365,        /* VAR_ALLOW_NOTIFY  */
+    VAR_REQUEST_XFR = 366,         /* VAR_REQUEST_XFR  */
+    VAR_ALLOW_AXFR_FALLBACK = 367, /* VAR_ALLOW_AXFR_FALLBACK  */
+    VAR_OUTGOING_INTERFACE = 368,  /* VAR_OUTGOING_INTERFACE  */
+    VAR_ANSWER_COOKIE = 369,       /* VAR_ANSWER_COOKIE  */
+    VAR_COOKIE_SECRET = 370,       /* VAR_COOKIE_SECRET  */
+    VAR_COOKIE_SECRET_FILE = 371,  /* VAR_COOKIE_SECRET_FILE  */
+    VAR_MAX_REFRESH_TIME = 372,    /* VAR_MAX_REFRESH_TIME  */
+    VAR_MIN_REFRESH_TIME = 373,    /* VAR_MIN_REFRESH_TIME  */
+    VAR_MAX_RETRY_TIME = 374,      /* VAR_MAX_RETRY_TIME  */
+    VAR_MIN_RETRY_TIME = 375,      /* VAR_MIN_RETRY_TIME  */
+    VAR_MIN_EXPIRE_TIME = 376,     /* VAR_MIN_EXPIRE_TIME  */
+    VAR_MULTI_MASTER_CHECK = 377,  /* VAR_MULTI_MASTER_CHECK  */
+    VAR_SIZE_LIMIT_XFR = 378,      /* VAR_SIZE_LIMIT_XFR  */
+    VAR_ZONESTATS = 379,           /* VAR_ZONESTATS  */
+    VAR_INCLUDE_PATTERN = 380,     /* VAR_INCLUDE_PATTERN  */
+    VAR_STORE_IXFR = 381,          /* VAR_STORE_IXFR  */
+    VAR_IXFR_SIZE = 382,           /* VAR_IXFR_SIZE  */
+    VAR_IXFR_NUMBER = 383,         /* VAR_IXFR_NUMBER  */
+    VAR_CREATE_IXFR = 384,         /* VAR_CREATE_IXFR  */
+    VAR_ZONE = 385,                /* VAR_ZONE  */
+    VAR_RRL_WHITELIST = 386,       /* VAR_RRL_WHITELIST  */
+    VAR_SERVERS = 387,             /* VAR_SERVERS  */
+    VAR_BINDTODEVICE = 388,        /* VAR_BINDTODEVICE  */
+    VAR_SETFIB = 389,              /* VAR_SETFIB  */
+    VAR_VERIFY = 390,              /* VAR_VERIFY  */
+    VAR_ENABLE = 391,              /* VAR_ENABLE  */
+    VAR_VERIFY_ZONE = 392,         /* VAR_VERIFY_ZONE  */
+    VAR_VERIFY_ZONES = 393,        /* VAR_VERIFY_ZONES  */
+    VAR_VERIFIER = 394,            /* VAR_VERIFIER  */
+    VAR_VERIFIER_COUNT = 395,      /* VAR_VERIFIER_COUNT  */
+    VAR_VERIFIER_FEED_ZONE = 396,  /* VAR_VERIFIER_FEED_ZONE  */
+    VAR_VERIFIER_TIMEOUT = 397     /* VAR_VERIFIER_TIMEOUT  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -266,70 +272,76 @@ extern int c_debug;
 #define VAR_DNSTAP 325
 #define VAR_DNSTAP_ENABLE 326
 #define VAR_DNSTAP_SOCKET_PATH 327
-#define VAR_DNSTAP_SEND_IDENTITY 328
-#define VAR_DNSTAP_SEND_VERSION 329
-#define VAR_DNSTAP_IDENTITY 330
-#define VAR_DNSTAP_VERSION 331
-#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 332
-#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 333
-#define VAR_REMOTE_CONTROL 334
-#define VAR_CONTROL_ENABLE 335
-#define VAR_CONTROL_INTERFACE 336
-#define VAR_CONTROL_PORT 337
-#define VAR_SERVER_KEY_FILE 338
-#define VAR_SERVER_CERT_FILE 339
-#define VAR_CONTROL_KEY_FILE 340
-#define VAR_CONTROL_CERT_FILE 341
-#define VAR_KEY 342
-#define VAR_ALGORITHM 343
-#define VAR_SECRET 344
-#define VAR_TLS_AUTH 345
-#define VAR_TLS_AUTH_DOMAIN_NAME 346
-#define VAR_TLS_AUTH_CLIENT_CERT 347
-#define VAR_TLS_AUTH_CLIENT_KEY 348
-#define VAR_TLS_AUTH_CLIENT_KEY_PW 349
-#define VAR_PATTERN 350
-#define VAR_NAME 351
-#define VAR_ZONEFILE 352
-#define VAR_NOTIFY 353
-#define VAR_PROVIDE_XFR 354
-#define VAR_ALLOW_QUERY 355
-#define VAR_AXFR 356
-#define VAR_UDP 357
-#define VAR_NOTIFY_RETRY 358
-#define VAR_ALLOW_NOTIFY 359
-#define VAR_REQUEST_XFR 360
-#define VAR_ALLOW_AXFR_FALLBACK 361
-#define VAR_OUTGOING_INTERFACE 362
-#define VAR_ANSWER_COOKIE 363
-#define VAR_COOKIE_SECRET 364
-#define VAR_COOKIE_SECRET_FILE 365
-#define VAR_MAX_REFRESH_TIME 366
-#define VAR_MIN_REFRESH_TIME 367
-#define VAR_MAX_RETRY_TIME 368
-#define VAR_MIN_RETRY_TIME 369
-#define VAR_MIN_EXPIRE_TIME 370
-#define VAR_MULTI_MASTER_CHECK 371
-#define VAR_SIZE_LIMIT_XFR 372
-#define VAR_ZONESTATS 373
-#define VAR_INCLUDE_PATTERN 374
-#define VAR_STORE_IXFR 375
-#define VAR_IXFR_SIZE 376
-#define VAR_IXFR_NUMBER 377
-#define VAR_CREATE_IXFR 378
-#define VAR_ZONE 379
-#define VAR_RRL_WHITELIST 380
-#define VAR_SERVERS 381
-#define VAR_BINDTODEVICE 382
-#define VAR_SETFIB 383
-#define VAR_VERIFY 384
-#define VAR_ENABLE 385
-#define VAR_VERIFY_ZONE 386
-#define VAR_VERIFY_ZONES 387
-#define VAR_VERIFIER 388
-#define VAR_VERIFIER_COUNT 389
-#define VAR_VERIFIER_FEED_ZONE 390
-#define VAR_VERIFIER_TIMEOUT 391
+#define VAR_DNSTAP_IP 328
+#define VAR_DNSTAP_TLS 329
+#define VAR_DNSTAP_TLS_SERVER_NAME 330
+#define VAR_DNSTAP_TLS_CERT_BUNDLE 331
+#define VAR_DNSTAP_TLS_CLIENT_KEY_FILE 332
+#define VAR_DNSTAP_TLS_CLIENT_CERT_FILE 333
+#define VAR_DNSTAP_SEND_IDENTITY 334
+#define VAR_DNSTAP_SEND_VERSION 335
+#define VAR_DNSTAP_IDENTITY 336
+#define VAR_DNSTAP_VERSION 337
+#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 338
+#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 339
+#define VAR_REMOTE_CONTROL 340
+#define VAR_CONTROL_ENABLE 341
+#define VAR_CONTROL_INTERFACE 342
+#define VAR_CONTROL_PORT 343
+#define VAR_SERVER_KEY_FILE 344
+#define VAR_SERVER_CERT_FILE 345
+#define VAR_CONTROL_KEY_FILE 346
+#define VAR_CONTROL_CERT_FILE 347
+#define VAR_KEY 348
+#define VAR_ALGORITHM 349
+#define VAR_SECRET 350
+#define VAR_TLS_AUTH 351
+#define VAR_TLS_AUTH_DOMAIN_NAME 352
+#define VAR_TLS_AUTH_CLIENT_CERT 353
+#define VAR_TLS_AUTH_CLIENT_KEY 354
+#define VAR_TLS_AUTH_CLIENT_KEY_PW 355
+#define VAR_PATTERN 356
+#define VAR_NAME 357
+#define VAR_ZONEFILE 358
+#define VAR_NOTIFY 359
+#define VAR_PROVIDE_XFR 360
+#define VAR_ALLOW_QUERY 361
+#define VAR_AXFR 362
+#define VAR_UDP 363
+#define VAR_NOTIFY_RETRY 364
+#define VAR_ALLOW_NOTIFY 365
+#define VAR_REQUEST_XFR 366
+#define VAR_ALLOW_AXFR_FALLBACK 367
+#define VAR_OUTGOING_INTERFACE 368
+#define VAR_ANSWER_COOKIE 369
+#define VAR_COOKIE_SECRET 370
+#define VAR_COOKIE_SECRET_FILE 371
+#define VAR_MAX_REFRESH_TIME 372
+#define VAR_MIN_REFRESH_TIME 373
+#define VAR_MAX_RETRY_TIME 374
+#define VAR_MIN_RETRY_TIME 375
+#define VAR_MIN_EXPIRE_TIME 376
+#define VAR_MULTI_MASTER_CHECK 377
+#define VAR_SIZE_LIMIT_XFR 378
+#define VAR_ZONESTATS 379
+#define VAR_INCLUDE_PATTERN 380
+#define VAR_STORE_IXFR 381
+#define VAR_IXFR_SIZE 382
+#define VAR_IXFR_NUMBER 383
+#define VAR_CREATE_IXFR 384
+#define VAR_ZONE 385
+#define VAR_RRL_WHITELIST 386
+#define VAR_SERVERS 387
+#define VAR_BINDTODEVICE 388
+#define VAR_SETFIB 389
+#define VAR_VERIFY 390
+#define VAR_ENABLE 391
+#define VAR_VERIFY_ZONE 392
+#define VAR_VERIFY_ZONES 393
+#define VAR_VERIFIER 394
+#define VAR_VERIFIER_COUNT 395
+#define VAR_VERIFIER_FEED_ZONE 396
+#define VAR_VERIFIER_TIMEOUT 397
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -346,7 +358,7 @@ union YYSTYPE
   char **strv;
   struct component *comp;
 
-#line 350 "configparser.h"
+#line 362 "configparser.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
